[gnome-software: 3/5] gs-details-page: Switch to using a 128px icon (if available)
- From: Philip Withnall <pwithnall src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-software: 3/5] gs-details-page: Switch to using a 128px icon (if available)
- Date: Fri, 6 Aug 2021 13:33:03 +0000 (UTC)
commit 4db489efae4ef5309737eb77cc6513bc83c24dc8
Author: Philip Withnall <pwithnall endlessos org>
Date: Thu Aug 5 17:35:21 2021 +0100
gs-details-page: Switch to using a 128px icon (if available)
As per the new designs.
Signed-off-by: Philip Withnall <pwithnall endlessos org>
Fixes: #1350
src/gs-details-page.c | 7 ++++---
src/gs-details-page.ui | 2 +-
2 files changed, 5 insertions(+), 4 deletions(-)
---
diff --git a/src/gs-details-page.ui b/src/gs-details-page.ui
index ce8d32b31..c82a46397 100644
--- a/src/gs-details-page.ui
+++ b/src/gs-details-page.ui
@@ -83,7 +83,7 @@
<property name="visible">True</property>
<property name="halign">start</property>
<property name="valign">start</property>
- <property name="pixel_size">96</property>
+ <property name="pixel_size">128</property>
<style>
<class name="icon-dropshadow"/>
</style>
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/gs-details-page.c b/src/gs-details-page.c
index 418289315..39baabc93 100644
--- a/src/gs-details-page.c
+++ b/src/gs-details-page.c
@@ -1018,16 +1018,17 @@ gs_details_page_refresh_all (GsDetailsPage *self)
tmp = gs_app_get_description (self->app);
gs_details_page_set_description (self, tmp);
/* set the icon; fall back to 64px if 96px isn’t available, which sometimes
* happens at 2× scale factor (hi-DPI) */
{
const struct {
guint icon_size;
const gchar *fallback_icon_name; /* (nullable) */
} icon_fallbacks[] = {
+ { 128, NULL },
{ 96, NULL },
{ 64, NULL },
- { 96, "system-component-application" },
+ { 128, "system-component-application" },
};
for (gsize i = 0; i < G_N_ELEMENTS (icon_fallbacks) && icon == NULL; i++) {
@@ -1018,16 +1018,17 @@ gs_details_page_refresh_all (GsDetailsPage *self)
tmp = gs_app_get_description (self->app);
gs_details_page_set_description (self, tmp);
- /* set the icon; fall back to 64px if 96px isn’t available, which sometimes
- * happens at 2× scale factor (hi-DPI) */
+ /* set the icon; fall back to 96px and 64px if 128px isn’t available,
+ * which sometimes happens at 2× scale factor (hi-DPI) */
{
const struct {